module GlossyApp

  class Session

    def create_file_asset(file_path, asset_folder_id)
      response = glossy_post_multipart("/asset_folders/#{asset_folder_id}/asset_files", {}, { 'asset_file[asset_file]' => file_path })

      if [200, 201].include?(response.status)
        asset_file = JSON.parse(response.body)
        return asset_file['asset_file']['id']
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end

      return nil
    end

    def delete_file_asset(asset_folder_id, asset_file_id)
      response = glossy_delete("/asset_folders/#{asset_folder_id}/asset_files/#{asset_file_id}")
      if [200, 201].include?(response.status)
        return true
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def create_assets_folder(name, parent_id = 'root')
      data = {
        'asset_folder' => {
          'parent_id' => parent_id,
          'name' => name
        }
      }

      response = glossy_post('/asset_folders', data.to_json, {"Content-Type" => "application/json"})
      if [200, 201].include?(response.status)
        asset_folder = JSON.parse(response.body)
        return asset_folder['asset_folder']['id']
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def delete_assets_folder(assets_folder_id)
      response = glossy_delete("/asset_folders/#{assets_folder_id}")
      if [200, 201].include?(response.status)
        return true
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def asset_folder_with_name_exists?(asset_folder_name, parent_folder_id='root')
      response = glossy_get "/asset_folders/#{parent_folder_id}"
      if [200].include?(response.status)
        root = JSON.parse(response.body)
        root['asset_folder']['children'].each do |folder|
          return folder['id'] if folder['name'] == asset_folder_name.to_s
        end
        return false
      else
        return false
      end
    end

  end

end
