module GlossyApp

  class Session

    def get_document_with_external_id(external_id)
      response = glossy_get "/documents"
      if [200].include?(response.status)
        json = JSON.parse(response.body)

        document_id = nil
        json['documents'].each do |document|
          if document['external_id'].to_s == external_id.to_s
            document_id = document['id']
            break
          end
        end

        if document_id
          return get_document(document_id)
        else
          return nil
        end
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end

    end

    def get_document(document_id)
      response = glossy_get "/documents/#{document_id}"
      if [200].include?(response.status)
        return JSON.parse(response.body)
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def create_document(publication_id, title, language = "en", external_id = nil, tag_list = [], published_at = nil)
      post_data = {
        'document' => {
          'publication_id' => publication_id,
          'title' => title,
          'external_id' => external_id,
          'language' => language,
          'tag_list' => tag_list,
          'published_at' => published_at
        }
      }

      response = glossy_post("/documents", post_data.to_json, {"Content-Type" => "application/json"})
      if [200, 201].include?(response.status)
        document = JSON.parse(response.body)

        document_id = document['document']['id']
        return document_id

      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def delete_document(document_id)
      response = glossy_delete("/documents/#{document_id}")
      if [200, 201].include?(response.status)
        return true
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def document_exists?(document_id)
      response = glossy_get "/documents/#{document_id}"
      if [200].include?(response.status)
        doc = JSON.parse(response.body)
        return document_id.to_s == doc['id'].to_s
      else
        return false
      end
    end

    def publish_document(document_id)
      response = glossy_post("/documents/#{document_id}/publish", {}.to_json)
      if [200, 201].include?(response.status)
        return true
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def unpublish_document(document_id)
      response = glossy_post("/documents/#{document_id}/unpublish", {}.to_json)
      if [200, 201].include?(response.status)
        return true
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

    def import_asset_file_into_document(document_id, asset_file_id)
      response = glossy_post("/documents/#{document_id}/import", {:asset_file_id => asset_file_id}.to_json, {"Content-Type" => "application/json"})
      if [200, 201].include?(response.status)
        return true
      else
        raise "Invalid response: #{response.inspect}\n#{response.body}"
      end
    end

  end

end
